@@ -1023,7 +1023,10 @@ MultiSequence *ComputeFinalAlignment (const TreeNode *tree, MultiSequence *seque
 
   MultiSequence *alignment = ProcessTree (tree, sequences, sparseMatrices, model);
 
+  SafeVector<int> oldOrdering;
   if (enableAlignOrder){
+    for (int i = 0; i < alignment->GetNumSequences(); i++)
+      oldOrdering.push_back (alignment->GetSequence(i)->GetSortLabel());
     alignment->SaveOrdering();
     enableAlignOrder = false;
   }
@@ -1037,6 +1040,12 @@ MultiSequence *ComputeFinalAlignment (const TreeNode *tree, MultiSequence *seque
 
   cerr << endl;
 
+  if (oldOrdering.size() > 0){
+    for (int i = 0; i < (int) oldOrdering.size(); i++){
+      alignment->GetSequence(i)->SetSortLabel(oldOrdering[i]);
+    }
+  }
+
   // return final alignment
   return alignment;
 }
@@ -1402,6 +1411,9 @@ void WriteAnnotation (MultiSequence *alignment,
   for (int i = 0; i < numSeqs; i++) seqs[i] = alignment->GetSequence(i)->GetDataPtr();
   SafeVector<pair<int,int> > active;
   active.reserve (numSeqs);
+
+  SafeVector<int> lab;
+  for (int i = 0; i < numSeqs; i++) lab.push_back(alignment->GetSequence(i)->GetSortLabel());
   
   // for every column
   for (int i = 1; i <= alignLength; i++){
@@ -1410,10 +1422,11 @@ void WriteAnnotation (MultiSequence *alignment,
     active.clear();
     for (int j = 0; j < numSeqs; j++){
       if (seqs[j][i] != '-'){
-	active.push_back (make_pair(j, ++position[j]));
+	active.push_back (make_pair(lab[j], ++position[j]));
       }
     }
     
+    sort (active.begin(), active.end());
     outfile << setw(4) << ComputeScore (active, sparseMatrices) << endl;
   }
   
